==> estateplat-common-1.2.4-20210927.061745-898-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSwsbxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version V1.0, 2021/9/23
 * @description 不动产税务申报信息
 */
@Table(name = "BDC_SWSBXX")
public class BdcSwsbxx {
    @Id
    private String swsbid;
    private String htbh;//合同编号
    private String proid;
    private String djxh;//登记序号
    private String nsrsbh;//纳税人识别号
    private String nsrmc;//纳税人名称
    private double ybtse;//应补退税额
    private String zrfcsfbz;//转让方承受方标记
    private String dzsphm;//电子税票号码
    private String skssjgdm;//税款所属机关
    private String kkfhm;//扣款返回码
    private String kkfhmc;//扣款返回信息

    public String getSwsbid() {
        return swsbid;
    }

    public void setSwsbid(String swsbid) {
        this.swsbid = swsbid;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getDjxh() {
        return djxh;
    }

    public void setDjxh(String djxh) {
        this.djxh = djxh;
    }

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public double getYbtse() {
        return ybtse;
    }

    public void setYbtse(double ybtse) {
        this.ybtse = ybtse;
    }

    public String getZrfcsfbz() {
        return zrfcsfbz;
    }

    public void setZrfcsfbz(String zrfcsfbz) {
        this.zrfcsfbz = zrfcsfbz;
    }

    public String getDzsphm() {
        return dzsphm;
    }

    public void setDzsphm(String dzsphm) {
        this.dzsphm = dzsphm;
    }

    public String getSkssjgdm() {
        return skssjgdm;
    }

    public void setSkssjgdm(String skssjgdm) {
        this.skssjgdm = skssjgdm;
    }

    public String getKkfhm() {
        return kkfhm;
    }

    public void setKkfhm(String kkfhm) {
        this.kkfhm = kkfhm;
    }

    public String getKkfhmc() {
        return kkfhmc;
    }

    public void setKkfhmc(String kkfhmc) {
        this.kkfhmc = kkfhmc;
    }
}

==> estateplat-common-1.2.4-20220628.015650-1056-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSwsbxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version V1.0, 2021/9/23
 * @description 不动产税务申报信息
 */
@Table(name = "BDC_SWSBXX")
public class BdcSwsbxx {
    @Id
    private String swsbid;
    private String htbh;//合同编号
    private String proid;
    private String djxh;//登记序号
    private String nsrsbh;//纳税人识别号
    private String nsrmc;//纳税人名称
    private double ybtse;//应补退税额
    private String zrfcsfbz;//转让方承受方标记
    private String dzsphm;//电子税票号码
    private String skssjgdm;//税款所属机关
    private String kkfhm;//扣款返回码
    private String kkfhmc;//扣款返回信息
    private String jfzt;//缴费状态

    public String getSwsbid() {
        return swsbid;
    }

    public void setSwsbid(String swsbid) {
        this.swsbid = swsbid;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getDjxh() {
        return djxh;
    }

    public void setDjxh(String djxh) {
        this.djxh = djxh;
    }

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public double getYbtse() {
        return ybtse;
    }

    public void setYbtse(double ybtse) {
        this.ybtse = ybtse;
    }

    public String getZrfcsfbz() {
        return zrfcsfbz;
    }

    public void setZrfcsfbz(String zrfcsfbz) {
        this.zrfcsfbz = zrfcsfbz;
    }

    public String getDzsphm() {
        return dzsphm;
    }

    public void setDzsphm(String dzsphm) {
        this.dzsphm = dzsphm;
    }

    public String getSkssjgdm() {
        return skssjgdm;
    }

    public void setSkssjgdm(String skssjgdm) {
        this.skssjgdm = skssjgdm;
    }

    public String getKkfhm() {
        return kkfhm;
    }

    public void setKkfhm(String kkfhm) {
        this.kkfhm = kkfhm;
    }

    public String getKkfhmc() {
        return kkfhmc;
    }

    public void setKkfhmc(String kkfhmc) {
        this.kkfhmc = kkfhmc;
    }

    public String getJfzt() {
        return jfzt;
    }

    public void setJfzt(String jfzt) {
        this.jfzt = jfzt;
    }
}
